﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Budget13.ViewModels;
using System.Data.Entity;
using Syncfusion.EJ.Export;
using Syncfusion.JavaScript.Models;
using Syncfusion.XlsIO;
using Syncfusion.Linq;
using System.Net;

namespace Budget13.Controllers
{
    public class AdminOCController : Controller
    {
        // GET: AdminOC

        private BudgetEntities db = new BudgetEntities();

        public ActionResult AdminOC()
        {
            OCRequestClassView Rmodel = new ViewModels.OCRequestClassView();

            if (Session["user"] == null)
                Session["user"] = new AuthUser();
            Rmodel.AUser = (AuthUser)Session["user"];
            if (Rmodel.AUser.Type != AccountTypes.Admin)
                return Redirect("NoAdminAccess.html");

            Session["OCddls"] = new OCddls();
            Rmodel.ddls = (OCddls)Session["OCddls"];

            Rmodel.ddlists = (ddlLists)Session["OCddls"];
            return View(Rmodel);
        }

        public ActionResult GetData(Syncfusion.JavaScript.DataManager dm)
        {
            System.Collections.IEnumerable Data = GetRequestData((AuthUser)Session["user"]);
            sgDataResult result = new sgDataResult();
            Syncfusion.JavaScript.DataSources.DataOperations operation = new Syncfusion.JavaScript.DataSources.DataOperations();
            if (dm.Sorted != null && dm.Sorted.Count > 0) //Sorting 
                Data = operation.PerformSorting(Data, dm.Sorted);
            if (dm.Where != null && dm.Where.Count > 0) //Filtering 
                Data = operation.PerformWhereFilter(Data, dm.Where, dm.Where[0].Operator);
            if (dm.Search != null && dm.Search.Count > 0) //searching 
                Data = operation.PerformSearching(Data, dm.Search);

            List<string> str = new List<string>();
            if (dm.Aggregates != null)
            {
                for (var i = 0; i < dm.Aggregates.Count; i++)
                    str.Add(dm.Aggregates[i].Field);
                result.aggregate = operation.PerformSelect(Data, str);
            }

            int count = Data.AsQueryable().Count();

            if (dm.Skip != 0)
                Data = operation.PerformSkip(Data, dm.Skip);
            if (dm.Take != 0)
                Data = operation.PerformTake(Data, dm.Take);
            result.count = count;
            result.result = Data;
            return Json(result, JsonRequestBehavior.AllowGet);

        }
        public ActionResult Update(Request value)
        {
            Request req = db.Requests.Single(o => o.RequestID == value.RequestID);
            db.Entry(req).CurrentValues.SetValues(value);
            db.Entry(req).State = EntityState.Modified;
            req.BU = value.BU;
            req.Updated = DateTime.Now;
            req.UpdatedBy = ((AuthUser)Session["user"]).Name;
            try
            {
                db.SaveChanges();
            }
            catch (Exception ex)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest, "Database Error: " + ex.Data);
            }
            return Json(value, JsonRequestBehavior.AllowGet);

        }

        public ActionResult Insert(Request value)
        {
            value.Created = DateTime.Now;
            value.CreatedBy = ((AuthUser)Session["user"]).Name;
            value.ISChoice = "OneCloud";
            db.Requests.Add(value);
            try
            {
                db.SaveChanges();
            }
            catch (Exception ex)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest, "Database Error: " + ex.Data);
            }
            db.Entry(value).Reload();
            return Json(value, JsonRequestBehavior.AllowGet);
        }

        private List<Request> GetRequestData(AuthUser u)
        {
            switch (u.Type)
            {
                case AccountTypes.Admin:
                    return (db.Requests.Where(a => a.ISChoice == "OneCloud").ToList());
                case AccountTypes.CCAdmin:
                    return (db.Requests.Where(a => a.ISChoice == "OneCloud" && a.BU == u.BU).ToList());
                case AccountTypes.Normal:
                    return (db.Requests.Where(a => a.ISChoice == "OneCloud" && a.BU == u.BU && a.CreatedBy == u.Name).ToList());
            }
            return (null);   //should never hit this..
        }

        public void ExportToExcel(string GridModel)
        {
            ExcelExport exp = new ExcelExport();
            var DataSource = GetRequestData((AuthUser)Session["user"]);
            GridProperties obj = (GridProperties)Syncfusion.JavaScript.Utils.DeserializeToModel(typeof(GridProperties), GridModel);
            exp.Export(obj, DataSource, "Export.xlsx", ExcelVersion.Excel2010, false, false, "flat-saffron");
        }

        //public ActionResult DataSource(string designation)
        //{
        //    var userTemplates = db.Requests.Where(c => c.OCSite == designation).ToList();
        //    var data = new List<object>();
        //    foreach (var Cust in userTemplates)
        //    {
        //        data.Add(new { value = Cust.OCvCore, text = Cust.OCvCore });
        //    }
        //    return Json(data, JsonRequestBehavior.AllowGet); //pass the filtered data to the client side
        //}




    }
}